summaryrefslogtreecommitdiffstats
path: root/kexi/formeditor/scripting/scriptIO.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/formeditor/scripting/scriptIO.h')
-rw-r--r--kexi/formeditor/scripting/scriptIO.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kexi/formeditor/scripting/scriptIO.h b/kexi/formeditor/scripting/scriptIO.h
index 319de0fd..9261d75c 100644
--- a/kexi/formeditor/scripting/scriptIO.h
+++ b/kexi/formeditor/scripting/scriptIO.h
@@ -42,17 +42,17 @@ class ScriptIO
/*! Save the evnts of a form.
Creates an \<events\> tag, and then one \<event\> tag for each event.
Each event tqcontains \<sender\> and \<receiver\> tags, with attributes depending on event type. */
- static bool saveFormEvents(TQDomNode &tqparentNode, FormScript *script);
- /*! Reads the \<events\> tag (\a tqparentNode), then creates and fills a FormScript object linked to this \a form.
+ static bool saveFormEvents(TQDomNode &parentNode, FormScript *script);
+ /*! Reads the \<events\> tag (\a parentNode), then creates and fills a FormScript object linked to this \a form.
The new FormScript object is then added to ScriptManager list.*/
- static bool loadFormEvents(TQDomNode &tqparentNode, Form *form, ScriptManager *manager);
+ static bool loadFormEvents(TQDomNode &parentNode, Form *form, ScriptManager *manager);
/*! Save only the events related to widget \a name in the FormScript \a fscript.
Used eg when copying/pasting widgets to keep also events related to it.*/
static bool saveAllEventsForWidget(TQObject *widget, FormScript *fscript, TQDomNode &node);
- static void saveEvent(Event *event, TQDomNode &tqparentNode);
- static void saveEventList(EventList *list, TQDomNode &tqparentNode);
+ static void saveEvent(Event *event, TQDomNode &parentNode);
+ static void saveEventList(EventList *list, TQDomNode &parentNode);
static void loadEvent(TQDomNode &node, EventList *list, Form *form);
protected: